@@ -1,4 +1,4 @@
-/* Copyright (C) 2003-2005 Jesper K. Pedersen <blackie@kde.org>
+/* Copyright (C) 2003-2006 Jesper K. Pedersen <blackie@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -39,6 +39,9 @@ public:
     virtual PointList anchorPoints() = 0;
     virtual Draw* clone() = 0;
     virtual QDomElement save( QDomDocument doc ) = 0;
+    void setCoordinates(const QPoint& p0, const QPoint& p1);
+    QPoint getStartPoint() const { return _startPos; }
+    QPoint getEndPoint() const { return _lastPos; }
 
 protected:
     QPoint _startPos;
